Program reads data from 2 files, order racers by time and print report that shows
the top 15 racers, and the rest after underline.

Usage:
> py main.py --files <folder_path> --order=[--asc | --desc]

shows list of drivers and optional order (default order is asc)

> py main.py --files <folder_path> driver “Sebastian Vettel”

shows statistic about driver